@@ -31,10 +31,7 @@ def console_main():
             help="显示版本号",
         )
         parser.add_argument(
-            "-c",
-            "--config_path",
-            help="查询配置文件路径",
-            action="store_true",
+            "-c", "--config_path", help="查询配置文件路径", action="store_true",
         )
         parser.add_argument(
             "-r", "--reset", help="重置配置项", action="store_true",
